/****************************************************************************
** Meta object code from reading C++ file 'training_widget.h'
**
** Created: Sat Feb 21 18:01:58 2009
**      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "training_widget.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'training_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 59
#error "This file was generated using the moc from 4.4.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_TrainingWidget[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // signals: signature, parameters, type, tag, flags
      16,   15,   15,   15, 0x05,
      35,   30,   15,   15, 0x05,
      58,   30,   15,   15, 0x05,
      84,   78,   15,   15, 0x05,

 // slots: signature, parameters, type, tag, flags
     105,   15,   15,   15, 0x0a,
     117,  115,   15,   15, 0x08,
     165,  115,   15,   15, 0x08,
     214,  208,   15,   15, 0x08,
     250,   15,   15,   15, 0x08,
     278,   15,   15,   15, 0x08,
     312,   15,   15,   15, 0x08,
     342,   15,   15,   15, 0x08,
     385,  378,   15,   15, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_TrainingWidget[] = {
    "TrainingWidget\0\0gameUpdated()\0iMsg\0"
    "notifyProblem(QString)\0notifyInfo(QString)\0"
    "iRack\0rackUpdated(QString)\0refresh()\0"
    ",\0enablePlayButton(QItemSelection,QItemSelection)\0"
    "showPreview(QItemSelection,QItemSelection)\0"
    "iText\0on_lineEditRack_textEdited(QString)\0"
    "on_pushButtonRack_clicked()\0"
    "on_pushButtonComplement_clicked()\0"
    "on_pushButtonSearch_clicked()\0"
    "on_pushButtonPlaySelected_clicked()\0"
    "iIndex\0on_treeViewResults_doubleClicked(QModelIndex)\0"
};

const QMetaObject TrainingWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TrainingWidget,
      qt_meta_data_TrainingWidget, 0 }
};

const QMetaObject *TrainingWidget::metaObject() const
{
    return &staticMetaObject;
}

void *TrainingWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_TrainingWidget))
        return static_cast<void*>(const_cast< TrainingWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int TrainingWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: gameUpdated(); break;
        case 1: notifyProblem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: notifyInfo((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: rackUpdated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: refresh(); break;
        case 5: enablePlayButton((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 6: showPreview((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 7: on_lineEditRack_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: on_pushButtonRack_clicked(); break;
        case 9: on_pushButtonComplement_clicked(); break;
        case 10: on_pushButtonSearch_clicked(); break;
        case 11: on_pushButtonPlaySelected_clicked(); break;
        case 12: on_treeViewResults_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        }
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void TrainingWidget::gameUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void TrainingWidget::notifyProblem(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void TrainingWidget::notifyInfo(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void TrainingWidget::rackUpdated(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_END_MOC_NAMESPACE
